@@ -52,7 +52,7 @@ class fastdocx(QMainWindow, Ui_MainWindow):
           self.setWindowIcon(QIcon('icon.ico'))
         except:
           pass
-        self.setWindowTitle('FastDocx文档自动化处理平台')
+        self.setWindowTitle('FastDocx')
         self.workdirButton.clicked.connect(self.workdirButtonClicked)
         self.process.clicked.connect(self.startProcess)
         self.listWidget.itemClicked.connect(self.setDetails)
